pyhsm.aead_cmd.YHSM_GeneratedAEAD

Package pyhsm :: Module aead_cmd :: Class YHSM_GeneratedAEAD |
[frames] | no frames]

# Class YHSM_GeneratedAEAD

Small class to represent a YHSM_AEAD_GENERATE_RESP.

Instance Methods
__init__(self, nonce, key_handle, aead) |
__repr__(self) |
save(self, filename) Store AEAD in a file. |
load(self, filename) Load AEAD from a file. |

Method Details

### save(self, filename) |
Store AEAD in a file. Parameters: `filename` (string) - File to create/overwrite

### load(self, filename) |
Load AEAD from a file. Parameters: `filename` (string) - File to read AEAD from